import logging
import os

from datetime import datetime


# 로그 폴더 생성
if os.path.exists("logs") == False:
    os.makedirs("logs")

# 포맷 설정
stream_formatter = logging.Formatter(
    "| %(asctime)s | %(levelname)s | - [!] %(message)s",
    datefmt='%Y-%m-%d %H:%M:%S'
)

file_formatter = logging.Formatter(
    "| %(asctime)s | %(levelname)s | - [!] %(message)s",
    datefmt='%Y-%m-%d %H:%M:%S'
)

# 로깅 모듈 설정
log = logging.getLogger("logger")
log.setLevel("DEBUG")

stream_handler = logging.StreamHandler()
stream_handler.setFormatter(stream_formatter)

# 포맷 적용 및 포맷 설정
now = datetime.now().strftime("%Y-%m-%d")

file_handler = logging.FileHandler(filename=f"logs/{now}.log", mode="a", encoding="UTF-8")
file_handler.setFormatter(file_formatter)

# 핸들러 추가
log.addHandler(stream_handler)
log.addHandler(file_handler)


import os, traceback

from discord.ext import commands

from koreanbots.integrations.discord import DiscordpyKoreanbots
from topgg import DBLClient 

from .logging import log


class BotNotReady(Exception):
    def __init__(self):
        """
        Sync 중 봇이 준비되어 있지 않으면 발생합니다.
        """

        super().__init__("The bot is not ready.")

class Bot(commands.Bot):

    def __init__(self, command_prefix=commands.when_mentioned, **options):
        
        self.koreanbots = None
        self.topgg = None

        super().__init__(command_prefix, **options)

    def sync_lists(self, koreanbots: str = None, topgg: str = None):
        """봇 리스트와 봇을 동기화합니다.

        ## Args:
            koreanbots: `str`
                한디리의 토큰이 입력됩니다.

        ## Returns:
            언어의 이름이 리턴됩니다.
        """

        if self.is_ready() == False:
            raise BotNotReady()

        if koreanbots:
            try:
                self.koreanbots = DiscordpyKoreanbots(
                    client=self,
                    api_key=koreanbots, 
                    run_task=True,
                )

            except Exception as e: return log.error(f"koreanbots.dev: {e}")

        if topgg:
            try:
                self.topgg = DBLClient(
                    bot=self,
                    token=topgg, 
                    autopost=True
                )

            except Exception as e: return log.error(f"top.gg: {e}")

        return log.info(f"Sync completed successfully.")

        
    async def cog_load(self, list_dir: str) -> None:

        for i in os.listdir(list_dir):
            if i.endswith(".py") == False:
                continue

            list_dir = list_dir.replace('./', '')
            
            try:
                self.load_extension(f"{list_dir}.{i[:-3]}")
                log.info(f"{list_dir}.{i[:-3]} has been loaded.")
                
            except:
                return log.error(traceback.format_exc())

        await self.sync_commands()
        
        print("")
        return log.info(f"{self.user} has finished loading.\n")


from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='ektis',
    version="0.0.1",
    description='This project is a module made for Hooknu and Plq',
    author='arin6145',
    author_email='help@hooknu.xyz',
    url='https://github.com/Arin6145/ektis',
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=['py-cord-dev[voice]', 'koreanbots', 'pymongo', 'topgg', 'pomice', 'Pillow', 'discord-cooldown', 'jsonly'],
    packages=find_packages(),
    keywords=['hooknu', 'timeelss', 'ektis', 'plq', 'fiter'],
    python_requires='>=3.8',
    package_data={},
    zip_safe=False,
    classifiers=[
        'Programming Language :: Python :: 3.11',
    ],
)